package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcDeviceLogMapper;
import com.ruoyi.oa.domain.CmcDeviceLog;
import com.ruoyi.oa.service.ICmcDeviceLogService;

/**
 * cmc仪器记录Service业务层处理
 * 
 * @author cmc
 * @date 2025-06-10
 */
@Service
public class CmcDeviceLogServiceImpl implements ICmcDeviceLogService 
{
    @Autowired
    private CmcDeviceLogMapper cmcDeviceLogMapper;

    /**
     * 查询cmc仪器记录
     * 
     * @param logId cmc仪器记录主键
     * @return cmc仪器记录
     */
    @Override
    public CmcDeviceLog selectCmcDeviceLogByLogId(Integer logId)
    {
        return cmcDeviceLogMapper.selectCmcDeviceLogByLogId(logId);
    }

    /**
     * 查询cmc仪器记录列表
     * 
     * @param cmcDeviceLog cmc仪器记录
     * @return cmc仪器记录
     */
    @Override
    public List<CmcDeviceLog> selectCmcDeviceLogList(CmcDeviceLog cmcDeviceLog)
    {
        return cmcDeviceLogMapper.selectCmcDeviceLogList(cmcDeviceLog);
    }

    /**
     * 新增cmc仪器记录
     * 
     * @param cmcDeviceLog cmc仪器记录
     * @return 结果
     */
    @Override
    public int insertCmcDeviceLog(CmcDeviceLog cmcDeviceLog)
    {
        return cmcDeviceLogMapper.insertCmcDeviceLog(cmcDeviceLog);
    }

    /**
     * 修改cmc仪器记录
     * 
     * @param cmcDeviceLog cmc仪器记录
     * @return 结果
     */
    @Override
    public int updateCmcDeviceLog(CmcDeviceLog cmcDeviceLog)
    {
        return cmcDeviceLogMapper.updateCmcDeviceLog(cmcDeviceLog);
    }

    /**
     * 批量删除cmc仪器记录
     * 
     * @param logIds 需要删除的cmc仪器记录主键
     * @return 结果
     */
    @Override
    public int deleteCmcDeviceLogByLogIds(Integer[] logIds)
    {
        return cmcDeviceLogMapper.deleteCmcDeviceLogByLogIds(logIds);
    }

    /**
     * 删除cmc仪器记录信息
     * 
     * @param logId cmc仪器记录主键
     * @return 结果
     */
    @Override
    public int deleteCmcDeviceLogByLogId(Integer logId)
    {
        return cmcDeviceLogMapper.deleteCmcDeviceLogByLogId(logId);
    }
}
